@@ -118,10 +118,10 @@ pub async fn test_list_type() {
 
 #[tokio::test]
 pub async fn test_array_type() {
-    struct QueryRoot;
+    struct Query;
 
     #[Object]
-    impl QueryRoot {
+    impl Query {
         async fn values(&self) -> [i32; 6] {
             [1, 2, 3, 4, 5, 6]
         }
@@ -132,7 +132,7 @@ pub async fn test_array_type() {
         }
     }
 
-    let schema = Schema::new(QueryRoot, EmptyMutation, EmptySubscription);
+    let schema = Schema::new(Query, EmptyMutation, EmptySubscription);
 
     assert_eq!(
         schema
